@@ -1,4 +1,5 @@
 # Copyright (c) 2007-2009 Pedro Matiello <pmatiello@gmail.com>
+#                         Peter Sagerson <peter.sagerson@gmail.com>
 #                         Johannes Reinhardt <jreinhardt@ist-dein-freund.de>
 #                         Rhys Ulerich <rhys.ulerich@gmail.com>
 #                         Roy Smith <roy@panix.com>
@@ -38,6 +39,7 @@ from pygraph.algorithms.utils import heappush, heappop
 from pygraph.classes.exceptions import NodeUnreachable
 from pygraph.classes.exceptions import NegativeWeightCycleError
 from pygraph.classes.digraph import digraph
+import bisect
 
 # Minimal spanning tree
 
@@ -70,7 +72,7 @@ def minimal_spanning_tree(graph, root=None):
     # Algorithm loop
     while (nroot is not None):
         ledge = _lightest_edge(graph, visited)
-        if (ledge == (-1, -1)):
+        if (ledge == None):
             if (root is not None):
                 break
             nroot = _first_unvisited(graph, visited)
@@ -116,13 +118,13 @@ def _lightest_edge(graph, visited):
     @rtype:  tuple
     @return: Lightest edge in graph going from a visited node to an unvisited one.
     """
-    lightest_edge = (-1, -1)
-    weight = -1
+    lightest_edge = None
+    weight = None
     for each in visited:
         for other in graph[each]:
             if (other not in visited):
                 w = graph.edge_weight((each, other))
-                if (w < weight or weight < 0):
+                if (weight is None or w < weight or weight < 0):
                     lightest_edge = (each, other)
                     weight = w
     return lightest_edge
@@ -152,29 +154,33 @@ def shortest_path(graph, source):
     Inaccessible target nodes do not appear in either dictionary.
     """
     # Initialization
-    dist     = { source: 0 }
-    previous = { source: None}
-    q = graph.nodes()
+    dist     = {source: 0}
+    previous = {source: None}
+
+    # This is a sorted queue of (dist, node) 2-tuples. The first item in the
+    # queue is always either a finalized node that we can ignore or the node
+    # with the smallest estimated distance from the source. Note that we will
+    # not remove nodes from this list as they are finalized; we just ignore them
+    # when they come up.
+    q = [(0, source)]
+
+    # The set of nodes for which we have final distances.
+    finished = set()
 
     # Algorithm loop
-    while q:
-        # examine_min process performed using O(nodes) pass here.
-        # May be improved using another examine_min data structure.
-        u = q[0]
-        for node in q[1:]:
-            if ((u not in dist) 
-                or (node in dist and dist[node] < dist[u])):
-                u = node
-        q.remove(u)
+    while len(q) > 0:
+        du, u = q.pop(0)
 
         # Process reachable, remaining nodes from u
-        if (u in dist):
+        if u not in finished:
+            finished.add(u)
             for v in graph[u]:
-                if v in q:
-                    alt = dist[u] + graph.edge_weight((u, v))
+                if v not in finished:
+                    alt = du + graph.edge_weight((u, v))
                     if (v not in dist) or (alt < dist[v]):
                         dist[v] = alt
                         previous[v] = u
+                        bisect.insort(q, (alt, v))
 
     return previous, dist
 
@@ -225,7 +231,9 @@ def shortest_path_bellman_ford(graph, source):
                 
     # detect negative weight cycles
     for src,dst in graph.edges():
-        if distance[src] + graph.edge_weight((src,dst)) < distance[dst]:
+        if src in distance and \
+           dst in distance and \
+           distance[src] + graph.edge_weight((src,dst)) < distance[dst]:
             raise NegativeWeightCycleError("Detected a negative weight cycle on edge (%s, %s)" % (src,dst))
         
     return predecessor, distance
