@@ -37,7 +37,7 @@ from pygraph.mixins.common import common
 from pygraph.mixins.basegraph import basegraph
 
 
-class graph ( basegraph, common, labeling, ):
+class graph(basegraph, common, labeling):
     """
     Graph class.
     
@@ -102,7 +102,7 @@ class graph ( basegraph, common, labeling, ):
         return node in self.node_neighbors
 
 
-    def add_node(self, node, attrs=[]):
+    def add_node(self, node, attrs=None):
         """
         Add given node to the graph.
         
@@ -115,6 +115,8 @@ class graph ( basegraph, common, labeling, ):
         @type  attrs: list
         @param attrs: List of node attributes specified as (attribute, value) tuples.
         """
+        if attrs is None:
+            attrs = []
         if (not node in self.node_neighbors):
             self.node_neighbors[node] = []
             self.node_attr[node] = attrs
@@ -146,7 +148,7 @@ class graph ( basegraph, common, labeling, ):
                 self.node_neighbors[v].append(u)
                 
             self.add_edge_attributes((u,v), attrs)        
-            self.set_edge_properties( (u, v), label=label, weight=wt )
+            self.set_edge_properties((u, v), label=label, weight=wt)
         else:
             raise AdditionError("Edge (%s, %s) already in graph" % (u, v))
 
@@ -225,4 +227,4 @@ class graph ( basegraph, common, labeling, ):
         @rtype: boolean
         @return: Whether this graph and the other are different.
         """
-        return not (self == other)
\ No newline at end of file
+        return not (self == other)
